Coverage for airflow.contrib.hooks.vertica_hook: 47%

# Coverage for airflow.contrib.hooks.vertica_hook : 47%

## 15 statements 7 run 8 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 | from vertica_python import connect from airflow.hooks.dbapi_hook import DbApiHook class VerticaHook(DbApiHook): ''' Interact with Vertica. ''' conn_name_attr = 'vertica_conn_id' default_conn_name = 'vertica_default' supports_autocommit = True def get_conn(self): """ Returns verticaql connection object """ conn = self.get_connection(self.vertica_conn_id) conn_config = { "user": conn.login, "password": conn.password, "database": conn.schema, } conn_config["host"] = conn.host or 'localhost' if not conn.port: conn_config["port"] = 5433 else: conn_config["port"] = int(conn.port) conn = connect(**conn_config) return conn